@@ -1,3 +1,4 @@
+import json
 from typing import ClassVar, Union
 from typing import Any, Dict, List, Optional
 
@@ -35,6 +36,7 @@ class TranscriptionOptions:
     HOTWORDS_WEIGHT: ClassVar[str] = 'hotwords_weight'
 
     COMMANDS_EXPRESSIONS: ClassVar[str] = 'commands_expression'
+    FIND_REPLACE_EXPRESSIONS: ClassVar[str] = 'find_replace_expressions'
 
 
 def parse_post_processing_options(headers) -> Dict[str, Any]:
@@ -135,7 +137,12 @@ def parse_formatting_config(headers) -> Dict[str, Any]:
     config: Dict[str, Any] = {}
 
     if COMMANDS_EXPRESSIONS_HEADER in headers:
-        config[TranscriptionOptions.COMMANDS_EXPRESSIONS] = headers[COMMANDS_EXPRESSIONS_HEADER]
+        command_configs = json.loads(headers[COMMANDS_EXPRESSIONS_HEADER])
+        config[TranscriptionOptions.COMMANDS_EXPRESSIONS] = command_configs
+
+    if FIND_REPLACE_EXPRESSIONS_HEADER in headers:
+        find_replace_configs = json.loads(headers[FIND_REPLACE_EXPRESSIONS_HEADER])
+        config[TranscriptionOptions.FIND_REPLACE_EXPRESSIONS] = find_replace_configs
 
     return config
 
