@@ -180,16 +180,17 @@ class Word:
         FACILITY: ClassVar[str] = 'FACILITY'
         WORK_OF_ART: ClassVar[str] = 'WORK_OF_ART'
         EVENT: ClassVar[str] = 'EVENT'
+        REPLACED: ClassVar[str] = 'REPLACED'
 
     def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[Union[str, int]] = None,
-                 confidence: float = 0, entity: Optional[str] = None, entity_group_id: Optional[int] = None):
+                 confidence: float = 0, entity: Optional[str] = None, entity_group_id: Optional[Union[int, str]] = None):
         self.word: str = word
         self.start_time: float = start_time_millis
         self.end_time: float = end_time_millis
         self.speaker: str = str(speaker) if speaker is not None else None
         self.confidence: float = confidence
         self.entity: Optional[str] = entity
-        self.entity_group_id: Optional[int] = entity_group_id
+        self.entity_group_id: Optional[str] = str(entity_group_id) if entity_group_id is not None else None
 
     def __str__(self):
         return f'''
